summaryrefslogtreecommitdiffstats
path: root/kmail
diff options
context:
space:
mode:
Diffstat (limited to 'kmail')
-rw-r--r--kmail/accountdialog.cpp8
-rw-r--r--kmail/accountmanager.cpp4
-rw-r--r--kmail/antispamwizard.cpp6
-rw-r--r--kmail/configuredialog.cpp6
-rw-r--r--kmail/favoritefolderview.cpp4
-rw-r--r--kmail/foldertreebase.cpp8
-rw-r--r--kmail/imapaccountbase.cpp8
-rw-r--r--kmail/index.cpp6
-rw-r--r--kmail/kmaccount.cpp4
-rw-r--r--kmail/kmacctlocal.cpp2
-rw-r--r--kmail/kmacctmaildir.cpp2
-rw-r--r--kmail/kmail.kcfg4
-rw-r--r--kmail/kmail_part.cpp12
-rw-r--r--kmail/kmcommands.cpp6
-rw-r--r--kmail/kmcomposewin.cpp14
-rw-r--r--kmail/kmedit.cpp2
-rw-r--r--kmail/kmfilterdlg.cpp2
-rw-r--r--kmail/kmfolderindex.cpp8
-rw-r--r--kmail/kmfoldermgr.cpp2
-rw-r--r--kmail/kmheaders.cpp10
-rw-r--r--kmail/kmkernel.cpp20
-rw-r--r--kmail/kmkernel.h2
-rw-r--r--kmail/kmmainwidget.cpp4
-rw-r--r--kmail/kmmainwin.cpp10
-rw-r--r--kmail/kmmsgpartdlg.cpp6
-rw-r--r--kmail/kmreaderwin.cpp6
-rw-r--r--kmail/kmsender.cpp4
-rw-r--r--kmail/kmservertest.cpp2
-rw-r--r--kmail/kmstartup.cpp4
-rw-r--r--kmail/kmsystemtray.cpp2
-rw-r--r--kmail/korghelper.cpp4
-rw-r--r--kmail/mailsourceviewer.cpp2
-rw-r--r--kmail/main.cpp10
-rw-r--r--kmail/managesievescriptsdialog.cpp2
-rw-r--r--kmail/searchwindow.cpp2
-rw-r--r--kmail/secondarywindow.cpp4
-rw-r--r--kmail/transportmanager.cpp2
-rw-r--r--kmail/vacationdialog.cpp2
38 files changed, 103 insertions, 103 deletions
diff --git a/kmail/accountdialog.cpp b/kmail/accountdialog.cpp
index c8ac7e29d..8565091d4 100644
--- a/kmail/accountdialog.cpp
+++ b/kmail/accountdialog.cpp
@@ -457,7 +457,7 @@ void AccountDialog::makeLocalAccountPage()
mLocal.identityLabel->setBuddy( mLocal.identityCombo );
topLayout->addWidget( mLocal.identityCombo, 10, 1 );
- connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
+ connect(tdeApp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
}
void AccountDialog::makeMaildirAccountPage()
@@ -557,7 +557,7 @@ void AccountDialog::makeMaildirAccountPage()
mMaildir.identityLabel->setBuddy( mMaildir.identityCombo );
topLayout->addWidget( mMaildir.identityCombo, 9, 1 );
- connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
+ connect(tdeApp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
}
@@ -823,7 +823,7 @@ void AccountDialog::makePopAccountPage()
vlay->addStretch();
- connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
+ connect(tdeApp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
}
@@ -1130,7 +1130,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
mSieveConfigEditor->layout()->setMargin( KDialog::marginHint() );
tabWidget->addTab( mSieveConfigEditor, i18n("&Filtering") );
- connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
+ connect(tdeApp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
}
diff --git a/kmail/accountmanager.cpp b/kmail/accountmanager.cpp
index 4f05eb165..8e4565c81 100644
--- a/kmail/accountmanager.cpp
+++ b/kmail/accountmanager.cpp
@@ -203,7 +203,7 @@ void AccountManager::processNextCheck( bool _newMail )
TQDataStream stream( params, IO_WriteOnly );
stream << static_cast<NetworkAccount*>( curAccount )->host();
- if ( kapp->dcopClient()->call( "kded", "networkstatus", "status(TQString)",
+ if ( tdeApp->dcopClient()->call( "kded", "networkstatus", "status(TQString)",
params, replyType, reply ) && ( replyType == "int" ) )
{
int result;
@@ -416,7 +416,7 @@ uint AccountManager::createId()
int newId;
do
{
- newId = kapp->random();
+ newId = tdeApp->random();
} while ( usedIds.find(newId) != usedIds.end() );
return newId;
diff --git a/kmail/antispamwizard.cpp b/kmail/antispamwizard.cpp
index 0627403ba..6c5373342 100644
--- a/kmail/antispamwizard.cpp
+++ b/kmail/antispamwizard.cpp
@@ -517,7 +517,7 @@ void AntiSpamWizard::checkToolAvailability()
}
else {
// check the availability of the application
- TDEApplication::kApplication()->processEvents( 200 );
+ tdeApp->processEvents( 200 );
if ( !checkForProgram( (*it).getExecutable() ) ) {
mInfoPage->addAvailableTool( (*it).getVisibleName() );
found = true;
@@ -540,9 +540,9 @@ void AntiSpamWizard::checkToolAvailability()
void AntiSpamWizard::slotHelpClicked()
{
if ( mMode == AntiSpam )
- kapp->invokeHelp( "the-anti-spam-wizard", "kmail" );
+ tdeApp->invokeHelp( "the-anti-spam-wizard", "kmail" );
else
- kapp->invokeHelp( "the-anti-virus-wizard", "kmail" );
+ tdeApp->invokeHelp( "the-anti-virus-wizard", "kmail" );
}
diff --git a/kmail/configuredialog.cpp b/kmail/configuredialog.cpp
index 2c5830abd..822da2c78 100644
--- a/kmail/configuredialog.cpp
+++ b/kmail/configuredialog.cpp
@@ -219,7 +219,7 @@ ConfigureDialog::ConfigureDialog( TQWidget *parent, const char *name, bool modal
KGuiItem(), User2, i18n( "Configure" ), parent, name, modal )
, mProfileDialog( 0 )
{
- KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
+ KWin::setIcons( winId(), tdeApp->icon(), tdeApp->miniIcon() );
showButton( User1, true );
addModule ( "kmail_config_identity", false );
@@ -1793,9 +1793,9 @@ void AppearancePage::ColorsTab::doLoadOther() {
mCloseToQuotaThreshold->setValue( GlobalSettings::closeToQuotaThreshold() );
static const TQColor defaultColor[ numColorNames ] = {
- kapp->palette().active().base(), // bg
+ tdeApp->palette().active().base(), // bg
TDEGlobalSettings::alternateBackgroundColor(), // alt bg
- kapp->palette().active().text(), // fg
+ tdeApp->palette().active().text(), // fg
TQColor( 0x00, 0x80, 0x00 ), // quoted l1
TQColor( 0x00, 0x70, 0x00 ), // quoted l2
TQColor( 0x00, 0x60, 0x00 ), // quoted l3
diff --git a/kmail/favoritefolderview.cpp b/kmail/favoritefolderview.cpp
index 543ea18fd..6e6c56bf5 100644
--- a/kmail/favoritefolderview.cpp
+++ b/kmail/favoritefolderview.cpp
@@ -222,7 +222,7 @@ void FavoriteFolderView::handleGroupwareFolder( KMFolderTreeItem *fti )
TQByteArray arg;
TQDataStream s( arg, IO_WriteOnly );
s << TQString( "kontact_knotesplugin" );
- kapp->dcopClient()->send( "kontact", "KontactIface", "selectPlugin(TQString)", arg );
+ tdeApp->dcopClient()->send( "kontact", "KontactIface", "selectPlugin(TQString)", arg );
break;
}
case KMail::ContentsTypeCalendar:
@@ -241,7 +241,7 @@ void FavoriteFolderView::handleGroupwareFolder( KMFolderTreeItem *fti )
s << TQString( "kontact_journalplugin" ); break;
default: assert( false );
}
- kapp->dcopClient()->send( "kontact", "KontactIface", "selectPlugin(TQString)", arg );
+ tdeApp->dcopClient()->send( "kontact", "KontactIface", "selectPlugin(TQString)", arg );
break;
}
default: break;
diff --git a/kmail/foldertreebase.cpp b/kmail/foldertreebase.cpp
index 10d7af2f1..7415591ee 100644
--- a/kmail/foldertreebase.cpp
+++ b/kmail/foldertreebase.cpp
@@ -74,7 +74,7 @@ void FolderTreeBase::contentsDropEvent(TQDropEvent * e)
int FolderTreeBase::dndMode(bool alwaysAsk)
{
int action = -1;
- int keybstate = kapp->keyboardModifiers();
+ int keybstate = tdeApp->keyboardModifiers();
if ( keybstate & TDEApplication::ControlModifier ) {
action = DRAG_COPY;
} else if ( keybstate & TDEApplication::ShiftModifier ) {
@@ -108,9 +108,9 @@ void FolderTreeBase::readColorConfig()
TDEConfig* conf = KMKernel::config();
// Custom/System color support
TDEConfigGroupSaver saver(conf, "Reader");
- TQColor c1=TQColor(kapp->palette().active().text());
+ TQColor c1=TQColor(tdeApp->palette().active().text());
TQColor c2=TQColor("blue");
- TQColor c4=TQColor(kapp->palette().active().base());
+ TQColor c4=TQColor(tdeApp->palette().active().base());
TQColor c5=TQColor("red");
if (!conf->readBoolEntry("defaultColors",true)) {
@@ -125,7 +125,7 @@ void FolderTreeBase::readColorConfig()
mPaintInfo.colBack = c4;
mPaintInfo.colCloseToQuota = c5;
}
- TQPalette newPal = kapp->palette();
+ TQPalette newPal = tdeApp->palette();
newPal.setColor( TQColorGroup::Base, mPaintInfo.colBack );
newPal.setColor( TQColorGroup::Text, mPaintInfo.colFore );
setPalette( newPal );
diff --git a/kmail/imapaccountbase.cpp b/kmail/imapaccountbase.cpp
index 47d169f9b..527ad334b 100644
--- a/kmail/imapaccountbase.cpp
+++ b/kmail/imapaccountbase.cpp
@@ -958,7 +958,7 @@ namespace KMail {
if ( errorCode == TDEIO::ERR_SERVER_TIMEOUT || errorCode == TDEIO::ERR_CONNECTION_BROKEN ) {
msg = i18n("The connection to the server %1 was unexpectedly closed or timed out. It will be re-established automatically if possible.").
arg( name() );
- KMessageBox::information( kapp->activeWindow(), msg, caption, "kmailConnectionBrokenErrorDialog" );
+ KMessageBox::information( tdeApp->activeWindow(), msg, caption, "kmailConnectionBrokenErrorDialog" );
// Show it in the status bar, in case the user has ticked "don't show again"
if ( errorCode == TDEIO::ERR_CONNECTION_BROKEN )
KPIM::BroadcastStatus::instance()->setStatusMsg(
@@ -968,9 +968,9 @@ namespace KMail {
i18n( "The connection to account %1 timed out." ).arg( name() ) );
} else {
if ( !errors.isEmpty() )
- KMessageBox::detailedError( kapp->activeWindow(), msg, errors.join("\n").prepend("<qt>"), caption );
+ KMessageBox::detailedError( tdeApp->activeWindow(), msg, errors.join("\n").prepend("<qt>"), caption );
else
- KMessageBox::error( kapp->activeWindow(), msg, caption );
+ KMessageBox::error( tdeApp->activeWindow(), msg, caption );
}
} else { // i.e. we have a chance to continue, ask the user about it
if ( errors.count() >= 3 ) { // there is no detailedWarningContinueCancel... (#86517)
@@ -978,7 +978,7 @@ namespace KMail {
msg = TQString( "<qt>") + context + error + '\n' + errors[2];
caption = errors[0];
}
- int ret = KMessageBox::warningContinueCancel( kapp->activeWindow(), msg, caption );
+ int ret = KMessageBox::warningContinueCancel( tdeApp->activeWindow(), msg, caption );
if ( ret == KMessageBox::Cancel ) {
jobsKilled = true;
killAllJobs( false );
diff --git a/kmail/index.cpp b/kmail/index.cpp
index c21e15d5b..f9b157d2f 100644
--- a/kmail/index.cpp
+++ b/kmail/index.cpp
@@ -264,7 +264,7 @@ void KMMsgIndex::clear() {
void KMMsgIndex::maintenance() {
#ifdef HAVE_INDEXLIB
- if ( mState != s_idle || kapp->hasPendingEvents() ) {
+ if ( mState != s_idle || tdeApp->hasPendingEvents() ) {
TQTimer::singleShot( 8000, this, TQ_SLOT( maintenance() ) );
return;
}
@@ -305,7 +305,7 @@ int KMMsgIndex::addMessage( TQ_UINT32 serNum ) {
void KMMsgIndex::act() {
kdDebug( 5006 ) << "KMMsgIndex::act()" << endl;
- if ( kapp->hasPendingEvents() ) {
+ if ( tdeApp->hasPendingEvents() ) {
//nah, some other time..
mTimer->start( 500 );
mSlowDown = true;
@@ -561,7 +561,7 @@ void KMMsgIndex::Search::act() {
mState = s_emitting;
// fall throu
case s_emitting:
- if ( kapp->hasPendingEvents() ) {
+ if ( tdeApp->hasPendingEvents() ) {
//nah, some other time..
mTimer->start( 250 );
mState = s_emitstopped;
diff --git a/kmail/kmaccount.cpp b/kmail/kmaccount.cpp
index a15def1f9..0d36844af 100644
--- a/kmail/kmaccount.cpp
+++ b/kmail/kmaccount.cpp
@@ -386,7 +386,7 @@ bool KMAccount::runPrecommand(const TQString &precommand)
kdDebug(5006) << "Running precommand " << precommand << endl;
if (!precommandProcess.start()) return false;
- kapp->eventLoop()->enterLoop();
+ tdeApp->eventLoop()->enterLoop();
return mPrecommandSuccess;
}
@@ -395,7 +395,7 @@ bool KMAccount::runPrecommand(const TQString &precommand)
void KMAccount::precommandExited(bool success)
{
mPrecommandSuccess = success;
- kapp->eventLoop()->exitLoop();
+ tdeApp->eventLoop()->exitLoop();
}
//-----------------------------------------------------------------------------
diff --git a/kmail/kmacctlocal.cpp b/kmail/kmacctlocal.cpp
index e42407e6c..fc045a330 100644
--- a/kmail/kmacctlocal.cpp
+++ b/kmail/kmacctlocal.cpp
@@ -88,7 +88,7 @@ void KMAcctLocal::processNewMail(bool)
break;
if (t.elapsed() >= 200) { //hardwired constant
- kapp->processEvents();
+ tdeApp->processEvents();
t.start();
}
}
diff --git a/kmail/kmacctmaildir.cpp b/kmail/kmacctmaildir.cpp
index 52b398e86..1770480de 100644
--- a/kmail/kmacctmaildir.cpp
+++ b/kmail/kmacctmaildir.cpp
@@ -181,7 +181,7 @@ void KMAcctMaildir::processNewMail(bool)
}
if (t.elapsed() >= 200) { //hardwired constant
- kapp->processEvents();
+ tdeApp->processEvents();
t.start();
}
diff --git a/kmail/kmail.kcfg b/kmail/kmail.kcfg
index 922e295c2..e12b04b32 100644
--- a/kmail/kmail.kcfg
+++ b/kmail/kmail.kcfg
@@ -557,10 +557,10 @@
<default>true</default>
</entry>
<entry name="ForegroundColor" type="Color" key="ForegroundColor">
- <default code="true">kapp->palette().active().text()</default>
+ <default code="true">tdeApp->palette().active().text()</default>
</entry>
<entry name="BackgroundColor" type="Color" key="BackgroundColor">
- <default code="true">kapp->palette().active().base()</default>
+ <default code="true">tdeApp->palette().active().base()</default>
</entry>
<entry name="FallbackCharacterEncoding" type="String" key="FallbackCharacterEncoding">
<default code="true"> TQCString(TQTextCodec::codecForLocale()->name()).lower() == "eucjp"? TQCString("jis7") : TQCString(TQTextCodec::codecForLocale()->name()).lower()</default>
diff --git a/kmail/kmcommands.cpp b/kmail/kmcommands.cpp
index 833144a86..ed706defc 100644
--- a/kmail/kmcommands.cpp
+++ b/kmail/kmcommands.cpp
@@ -1705,7 +1705,7 @@ KMCommand::Result KMSeStatusCommand::execute()
f->setStatus( (*it2), mStatus, mToggle );
++it2;
}
- //kapp->dcopClient()->emitDCOPSignal( "unreadCountChanged()", TQByteArray() );
+ //tdeApp->dcopClient()->emitDCOPSignal( "unreadCountChanged()", TQByteArray() );
return OK;
}
@@ -1755,7 +1755,7 @@ KMCommand::Result KMFilterActionCommand::execute()
TQString statusMsg = i18n("Filtering message %1 of %2");
statusMsg = statusMsg.arg( msgCount ).arg( msgCountToFilter );
KPIM::BroadcastStatus::instance()->setStatusMsg( statusMsg );
- TDEApplication::kApplication()->eventLoop()->processEvents( TQEventLoop::ExcludeUserInput, 50 );
+ tdeApp->eventLoop()->processEvents( TQEventLoop::ExcludeUserInput, 50 );
}
int filterResult = kmkernel->filterMgr()->process( serNum, mFilter );
@@ -3586,7 +3586,7 @@ KMCommand::Result CreateTodoCommand::execute()
tf.file()->writeBlock( msg->asDwString().c_str(), msg->asDwString().length() );
tf.close();
- KCalendarIface_stub *iface = new KCalendarIface_stub( kapp->dcopClient(), "korganizer", "CalendarIface" );
+ KCalendarIface_stub *iface = new KCalendarIface_stub( tdeApp->dcopClient(), "korganizer", "CalendarIface" );
iface->openTodoEditor( i18n("Mail: %1").arg( msg->subject() ), txt, uri,
tf.name(), TQStringList(), "message/rfc822", true );
delete iface;
diff --git a/kmail/kmcomposewin.cpp b/kmail/kmcomposewin.cpp
index f83ac714f..f4ead799a 100644
--- a/kmail/kmcomposewin.cpp
+++ b/kmail/kmcomposewin.cpp
@@ -647,15 +647,15 @@ bool KMComposeWin::event(TQEvent *e)
void KMComposeWin::readColorConfig(void)
{
if ( GlobalSettings::self()->useDefaultColors() ) {
- mForeColor = TQColor(kapp->palette().active().text());
- mBackColor = TQColor(kapp->palette().active().base());
+ mForeColor = TQColor(tdeApp->palette().active().text());
+ mBackColor = TQColor(tdeApp->palette().active().base());
} else {
mForeColor = GlobalSettings::self()->foregroundColor();
mBackColor = GlobalSettings::self()->backgroundColor();
}
// Color setup
- mPalette = kapp->palette();
+ mPalette = tdeApp->palette();
TQColorGroup cgrp = mPalette.active();
cgrp.setColor( TQColorGroup::Base, mBackColor);
cgrp.setColor( TQColorGroup::Text, mForeColor);
@@ -2240,7 +2240,7 @@ bool KMComposeWin::queryClose ()
{
if ( !mEditor->checkExternalEditorFinished() )
return false;
- if ( kmkernel->shuttingDown() || kapp->sessionSaving() )
+ if ( kmkernel->shuttingDown() || tdeApp->sessionSaving() )
return true;
if ( mComposer && mComposer->isPerformingSignOperation() ) // since the non-gpg-agent gpg plugin gets a passphrase using TQDialog::exec()
return false; // the user can try to close the window, which destroys mComposer mid-call.
@@ -3830,7 +3830,7 @@ void KMComposeWin::slotCopy()
#endif
TQKeyEvent k(TQEvent::KeyPress, Key_C, 0, ControlButton);
- kapp->notify(fw, &k);
+ tdeApp->notify(fw, &k);
}
@@ -4576,7 +4576,7 @@ void KMComposeWin::insertSignature( SignaturePlacement placement )
//-----------------------------------------------------------------------------
void KMComposeWin::slotHelp()
{
- kapp->invokeHelp();
+ tdeApp->invokeHelp();
}
//-----------------------------------------------------------------------------
@@ -4998,7 +4998,7 @@ void KMComposeWin::slotSpellcheckConfig()
qtd.addTab (&mKSpellConfig, i18n("Spellchecker"));
qtd.setCancelButton ();
- twin.setIcons (qtd.winId(), kapp->icon(), kapp->miniIcon());
+ twin.setIcons (qtd.winId(), tdeApp->icon(), tdeApp->miniIcon());
qtd.setCancelButton(KStdGuiItem::cancel().text());
qtd.setOkButton(KStdGuiItem::ok().text());
diff --git a/kmail/kmedit.cpp b/kmail/kmedit.cpp
index 3f6b5d8ff..e19b0f46b 100644
--- a/kmail/kmedit.cpp
+++ b/kmail/kmedit.cpp
@@ -250,7 +250,7 @@ void KMEdit::initializeAutoSpellChecking()
TQColor defaultColor1( 0x00, 0x80, 0x00 ); // defaults from kmreaderwin.cpp
TQColor defaultColor2( 0x00, 0x70, 0x00 );
TQColor defaultColor3( 0x00, 0x60, 0x00 );
- TQColor defaultForeground( kapp->palette().active().text() );
+ TQColor defaultForeground( tdeApp->palette().active().text() );
TQColor c = TQt::red;
TDEConfigGroup readerConfig( KMKernel::config(), "Reader" );
diff --git a/kmail/kmfilterdlg.cpp b/kmail/kmfilterdlg.cpp
index e6d1668f1..51fd8ac9a 100644
--- a/kmail/kmfilterdlg.cpp
+++ b/kmail/kmfilterdlg.cpp
@@ -134,7 +134,7 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
Ok /* default btn */, false /* separator */),
bPopFilter(popFilter)
{
- KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
+ KWin::setIcons( winId(), tdeApp->icon(), tdeApp->miniIcon() );
setHelp( (bPopFilter)? KMPopFilterDlgHelpAnchor: KMFilterDlgHelpAnchor );
setButtonText( User1, i18n("Import") );
setButtonText( User2, i18n("Export") );
diff --git a/kmail/kmfolderindex.cpp b/kmail/kmfolderindex.cpp
index 9b60b25ce..42b5d0c5b 100644
--- a/kmail/kmfolderindex.cpp
+++ b/kmail/kmfolderindex.cpp
@@ -363,14 +363,14 @@ bool KMFolderIndex::readIndexHeader(int *gv)
createIndexFromContents();
return false;
} else if(indexVersion > INDEX_VERSION) {
- kapp->setOverrideCursor(KCursor::arrowCursor());
+ tdeApp->setOverrideCursor(KCursor::arrowCursor());
int r = KMessageBox::questionYesNo(0,
i18n(
"The mail index for '%1' is from an unknown version of KMail (%2).\n"
"This index can be regenerated from your mail folder, but some "
"information, including status flags, may be lost. Do you wish "
"to downgrade your index file?") .arg(name()) .arg(indexVersion), TQString(), i18n("Downgrade"), i18n("Do Not Downgrade") );
- kapp->restoreOverrideCursor();
+ tdeApp->restoreOverrideCursor();
if (r == KMessageBox::Yes)
createIndexFromContents();
return false;
@@ -524,11 +524,11 @@ KMMsgInfo* KMFolderIndex::setIndexEntry( int idx, KMMessage *msg )
void KMFolderIndex::recreateIndex( bool readIndexAfterwards )
{
- kapp->setOverrideCursor(KCursor::arrowCursor());
+ tdeApp->setOverrideCursor(KCursor::arrowCursor());
KMessageBox::information(0,
i18n("The mail index for '%1' is corrupted and will be regenerated now, "
"but some information, like status flags, might get lost.").arg(name()));
- kapp->restoreOverrideCursor();
+ tdeApp->restoreOverrideCursor();
createIndexFromContents();
if ( readIndexAfterwards ) {
readIndex();
diff --git a/kmail/kmfoldermgr.cpp b/kmail/kmfoldermgr.cpp
index 94bbc2b94..a0c4ee2c0 100644
--- a/kmail/kmfoldermgr.cpp
+++ b/kmail/kmfoldermgr.cpp
@@ -561,7 +561,7 @@ uint KMFolderMgr::createId()
int newId;
do
{
- newId = kapp->random();
+ newId = tdeApp->random();
} while ( findById( newId ) != 0 );
return newId;
diff --git a/kmail/kmheaders.cpp b/kmail/kmheaders.cpp
index fe5531bee..06de88fbc 100644
--- a/kmail/kmheaders.cpp
+++ b/kmail/kmheaders.cpp
@@ -428,10 +428,10 @@ void KMHeaders::readColorConfig (void)
TDEConfig* config = KMKernel::config();
// Custom/System colors
TDEConfigGroupSaver saver(config, "Reader");
- TQColor c1=TQColor(kapp->palette().active().text());
+ TQColor c1=TQColor(tdeApp->palette().active().text());
TQColor c2=TQColor("red");
TQColor c3=TQColor("blue");
- TQColor c4=TQColor(kapp->palette().active().base());
+ TQColor c4=TQColor(tdeApp->palette().active().base());
TQColor c5=TQColor(0,0x7F,0);
TQColor c6=TQColor(0,0x98,0);
TQColor c7=TDEGlobalSettings::alternateBackgroundColor();
@@ -439,7 +439,7 @@ void KMHeaders::readColorConfig (void)
if (!config->readBoolEntry("defaultColors",true)) {
mPaintInfo.colFore = config->readColorEntry("ForegroundColor",&c1);
mPaintInfo.colBack = config->readColorEntry("BackgroundColor",&c4);
- TQPalette newPal = kapp->palette();
+ TQPalette newPal = tdeApp->palette();
newPal.setColor( TQColorGroup::Base, mPaintInfo.colBack );
newPal.setColor( TQColorGroup::Text, mPaintInfo.colFore );
setPalette( newPal );
@@ -452,7 +452,7 @@ void KMHeaders::readColorConfig (void)
else {
mPaintInfo.colFore = c1;
mPaintInfo.colBack = c4;
- TQPalette newPal = kapp->palette();
+ TQPalette newPal = tdeApp->palette();
newPal.setColor( TQColorGroup::Base, c4 );
newPal.setColor( TQColorGroup::Text, c1 );
setPalette( newPal );
@@ -1452,7 +1452,7 @@ void KMHeaders::applyFiltersOnMsg()
TQString statusMsg = i18n("Filtering message %1 of %2");
statusMsg = statusMsg.arg( msgCount ).arg( msgCountToFilter );
KPIM::BroadcastStatus::instance()->setStatusMsg( statusMsg );
- TDEApplication::kApplication()->eventLoop()->processEvents( TQEventLoop::ExcludeUserInput, 50 );
+ tdeApp->eventLoop()->processEvents( TQEventLoop::ExcludeUserInput, 50 );
}
KMFolder *folder = 0;
diff --git a/kmail/kmkernel.cpp b/kmail/kmkernel.cpp
index 0f1d34ed9..1978e092c 100644
--- a/kmail/kmkernel.cpp
+++ b/kmail/kmkernel.cpp
@@ -390,7 +390,7 @@ void KMKernel::openReader( bool onlyCheck )
// Activate window - doing this instead of KWin::activateWindow(mWin->winId());
// so that it also works when called from KMailApplication::newInstance()
#if defined TQ_WS_X11 && ! defined K_WS_TQTONLY
- TDEStartupInfo::setNewStartupId( mWin, kapp->startupId() );
+ TDEStartupInfo::setNewStartupId( mWin, tdeApp->startupId() );
#endif
}
}
@@ -460,7 +460,7 @@ int KMKernel::openComposer (const TQString &to, const TQString &cc,
// Activate window - doing this instead of KWin::activateWindow(cWin->winId());
// so that it also works when called from KMailApplication::newInstance()
#if defined TQ_WS_X11 && ! defined K_WS_TQTONLY
- TDEStartupInfo::setNewStartupId( cWin, kapp->startupId() );
+ TDEStartupInfo::setNewStartupId( cWin, tdeApp->startupId() );
#endif
}
return 1;
@@ -607,7 +607,7 @@ int KMKernel::openComposer (const TQString &to, const TQString &cc,
// Activate window - doing this instead of KWin::activateWindow(cWin->winId());
// so that it also works when called from KMailApplication::newInstance()
#if defined TQ_WS_X11 && ! defined K_WS_TQTONLY
- TDEStartupInfo::setNewStartupId( cWin, kapp->startupId() );
+ TDEStartupInfo::setNewStartupId( cWin, tdeApp->startupId() );
#endif
} else {
cWin->setAutoDeleteWindow( true );
@@ -653,7 +653,7 @@ DCOPRef KMKernel::openComposer(const TQString &to, const TQString &cc,
// Activate window - doing this instead of KWin::activateWindow(cWin->winId());
// so that it also works when called from KMailApplication::newInstance()
#if defined TQ_WS_X11 && ! defined K_WS_TQTONLY
- TDEStartupInfo::setNewStartupId( cWin, kapp->startupId() );
+ TDEStartupInfo::setNewStartupId( cWin, tdeApp->startupId() );
#endif
}
@@ -1357,7 +1357,7 @@ void KMKernel::slotSenderFinished()
good, Folder manager go compact sent-mail and outbox
clean up stage1 (release folders and config, unregister from dcop)
-- another kmail may start now ---
- kapp->quit();
+ tdeApp->quit();
}
*/
@@ -1744,7 +1744,7 @@ bool KMKernel::doSessionManagement()
{
// Do session management
- if (kapp->isRestored()){
+ if (tdeApp->isRestored()){
int n = 1;
while (KMMainWin::canBeRestored(n)){
//only restore main windows! (Matthias);
@@ -1884,7 +1884,7 @@ bool KMKernel::transferMail( TQString & destinationDir )
#if 0
// disabled for now since moving fails in certain cases (e.g. if symbolic links are involved)
- const TQString kmailName = kapp->aboutData()->programName();
+ const TQString kmailName = tdeApp->aboutData()->programName();
TQString msg;
if ( TDEIO::NetAccess::exists( destinationDir, true, 0 ) ) {
// if destinationDir exists, we need to warn about possible
@@ -1962,7 +1962,7 @@ void KMKernel::kmailMsgHandler(TQtMsgType aType, const char* aMsg)
case TQtFatalMsg: // Hm, what about using kdFatal() here?
ungrabPtrKb();
- kdDebug(5006) << kapp->caption() << " fatal error "
+ kdDebug(5006) << tdeApp->caption() << " fatal error "
<< aMsg << endl;
KMessageBox::error(0, aMsg);
abort();
@@ -2344,7 +2344,7 @@ void KMKernel::selectFolder( TQString folderPath )
KMMainWidget *KMKernel::getKMMainWidget()
{
//This could definitely use a speadup
- TQWidgetList *l = kapp->topLevelWidgets();
+ TQWidgetList *l = tdeApp->topLevelWidgets();
TQWidgetListIt it( *l );
TQWidget *wid;
@@ -2420,7 +2420,7 @@ KMFolder* KMKernel::findFolderById( const TQString& idString )
::KIMProxy* KMKernel::imProxy()
{
- return KIMProxy::instance( kapp->dcopClient() );
+ return KIMProxy::instance( tdeApp->dcopClient() );
}
void KMKernel::enableMailCheck()
diff --git a/kmail/kmkernel.h b/kmail/kmkernel.h
index 06c563a50..cc148f0f7 100644
--- a/kmail/kmkernel.h
+++ b/kmail/kmkernel.h
@@ -486,7 +486,7 @@ private:
TQString the_previousVersion;
/** is this the first start? read from config */
bool the_firstStart;
- /** are we starting up? set in main.cpp directly before kapp->exec() */
+ /** are we starting up? set in main.cpp directly before tdeApp->exec() */
bool the_startingUp;
/** are we going down? set from here */
bool the_shuttingDown;
diff --git a/kmail/kmmainwidget.cpp b/kmail/kmmainwidget.cpp
index bdae84d22..ec46d773f 100644
--- a/kmail/kmmainwidget.cpp
+++ b/kmail/kmmainwidget.cpp
@@ -856,7 +856,7 @@ void KMMainWidget::slotFind()
//-----------------------------------------------------------------------------
void KMMainWidget::slotHelp()
{
- kapp->invokeHelp();
+ tdeApp->invokeHelp();
}
@@ -928,7 +928,7 @@ void KMMainWidget::slotMailChecked( bool newMail, bool sendOnCheck,
if ( !newMail || newInFolder.isEmpty() )
return;
- kapp->dcopClient()->emitDCOPSignal( "unreadCountChanged()", TQByteArray() );
+ tdeApp->dcopClient()->emitDCOPSignal( "unreadCountChanged()", TQByteArray() );
// build summary for new mail message
bool showNotification = false;
diff --git a/kmail/kmmsgpartdlg.cpp b/kmail/kmmsgpartdlg.cpp
index 9cf26fbed..3b63badc8 100644
--- a/kmail/kmmsgpartdlg.cpp
+++ b/kmail/kmmsgpartdlg.cpp
@@ -89,7 +89,7 @@ KMMsgPartDialog::KMMsgPartDialog( const TQString & caption,
"<p>normally, you do not need to touch this setting, since the "
"type of the file is automatically checked; but, sometimes, %1 "
"may not detect the type correctly -- here is where you can fix "
- "that.</p></qt>").arg( kapp->aboutData()->programName() );
+ "that.</p></qt>").arg( tdeApp->aboutData()->programName() );
TQWhatsThis::add( mMimeType, msg );
// row 1: Size label:
@@ -102,7 +102,7 @@ KMMsgPartDialog::KMMsgPartDialog( const TQString & caption,
"because calculating the exact size would take too much time; "
"when this is the case, it will be made visible by adding "
"\"(est.)\" to the size displayed.</p></qt>")
- .arg( kapp->aboutData()->programName() );
+ .arg( tdeApp->aboutData()->programName() );
TQWhatsThis::add( mSize, msg );
// row 2: "Name" lineedit and label:
@@ -148,7 +148,7 @@ KMMsgPartDialog::KMMsgPartDialog( const TQString & caption,
"binary data, but consists of pure text -- in this case, choosing "
"\"quoted-printable\" over the default \"base64\" will save up "
"to 25% in resulting message size.</p></qt>")
- .arg( kapp->aboutData()->programName() );
+ .arg( tdeApp->aboutData()->programName() );
TQWhatsThis::add( label, msg );
TQWhatsThis::add( mEncoding, msg );
diff --git a/kmail/kmreaderwin.cpp b/kmail/kmreaderwin.cpp
index e7df43ca4..09c3701f6 100644
--- a/kmail/kmreaderwin.cpp
+++ b/kmail/kmreaderwin.cpp
@@ -1297,7 +1297,7 @@ void KMReaderWin::displaySplashPage( const TQString &info )
TQString location = locate("data", "kmail/about/main.html");
TQString content = KPIM::kFileToString(location);
content = content.arg( locate( "data", "libtdepim/about/kde_infopage.css" ) );
- if ( kapp->reverseLayout() )
+ if ( tdeApp->reverseLayout() )
content = content.arg( "@import \"%1\";" ).arg( locate( "data", "libtdepim/about/kde_infopage_rtl.css" ) );
else
content = content.arg( "" );
@@ -2163,7 +2163,7 @@ void KMReaderWin::slotToggleMimePartTree()
//-----------------------------------------------------------------------------
void KMReaderWin::slotCopySelectedText()
{
- kapp->clipboard()->setText( mViewer->selectedText() );
+ tdeApp->clipboard()->setText( mViewer->selectedText() );
}
@@ -2465,7 +2465,7 @@ void KMReaderWin::slotDocumentChanged()
void KMReaderWin::slotTextSelected(bool)
{
TQString temp = mViewer->selectedText();
- kapp->clipboard()->setText(temp);
+ tdeApp->clipboard()->setText(temp);
}
//-----------------------------------------------------------------------------
diff --git a/kmail/kmsender.cpp b/kmail/kmsender.cpp
index 5e8e4b415..cf1e72728 100644
--- a/kmail/kmsender.cpp
+++ b/kmail/kmsender.cpp
@@ -474,7 +474,7 @@ void KMSender::doSendMsg()
true );
connect( mProgressItem, TQ_SIGNAL(progressItemCanceled(KPIM::ProgressItem*)),
this, TQ_SLOT( slotAbortSend() ) );
- kapp->ref();
+ tdeApp->ref();
mSendInProgress = true;
}
@@ -632,7 +632,7 @@ void KMSender::cleanup(void)
if (mSendProc && mSendProcStarted) mSendProc->finish();
mSendProc = 0;
mSendProcStarted = false;
- if (mSendInProgress) kapp->deref();
+ if (mSendInProgress) tdeApp->deref();
mSendInProgress = false;
if (mCurrentMsg)
{
diff --git a/kmail/kmservertest.cpp b/kmail/kmservertest.cpp
index 7383060d3..9173d69cb 100644
--- a/kmail/kmservertest.cpp
+++ b/kmail/kmservertest.cpp
@@ -166,7 +166,7 @@ void KMServerTest::slotSlaveResult(TDEIO::Slave *aSlave, int error,
if ( error )
{
mJob = 0;
- KMessageBox::error( kapp->activeWindow(),
+ KMessageBox::error( tdeApp->activeWindow(),
TDEIO::buildErrorString( error, errorText ),
i18n("Error") );
emit capabilities( mListNormal, mListSSL );
diff --git a/kmail/kmstartup.cpp b/kmail/kmstartup.cpp
index 8a3f8f741..dd8a43865 100644
--- a/kmail/kmstartup.cpp
+++ b/kmail/kmstartup.cpp
@@ -137,12 +137,12 @@ void checkConfigUpdates() {
void lockOrDie() {
// Check and create a lock file to prevent concurrent access to kmail files
- TQString appName = kapp->instanceName();
+ TQString appName = tdeApp->instanceName();
if ( appName.isEmpty() )
appName = "kmail";
TQString programName;
- const TDEAboutData *about = kapp->aboutData();
+ const TDEAboutData *about = tdeApp->aboutData();
if ( about )
programName = about->programName();
if ( programName.isEmpty() )
diff --git a/kmail/kmsystemtray.cpp b/kmail/kmsystemtray.cpp
index b6e1f9691..45d8bfc95 100644
--- a/kmail/kmsystemtray.cpp
+++ b/kmail/kmsystemtray.cpp
@@ -138,7 +138,7 @@ void KMSystemTray::buildPopupMenu()
void KMSystemTray::tray_quit()
{
// Quit all of KMail
- kapp->quit();
+ tdeApp->quit();
}
KMSystemTray::~KMSystemTray()
diff --git a/kmail/korghelper.cpp b/kmail/korghelper.cpp
index cace2a102..a33e02be6 100644
--- a/kmail/korghelper.cpp
+++ b/kmail/korghelper.cpp
@@ -35,12 +35,12 @@ void KMail::KorgHelper::ensureRunning()
// [that's not the case when kontact was already running, but korganizer not loaded into it...]
static const char* const dcopObjectId = "KOrganizerIface";
TQCString dummy;
- if ( !kapp->dcopClient()->findObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) ) {
+ if ( !tdeApp->dcopClient()->findObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) ) {
DCOPRef ref( dcopService, dcopService ); // talk to the TDEUniqueApplication or its kontact wrapper
DCOPReply reply = ref.call( "load()" );
if ( reply.isValid() && (bool)reply ) {
kdDebug() << "Loaded " << dcopService << " successfully" << endl;
- Q_ASSERT( kapp->dcopClient()->findObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) );
+ Q_ASSERT( tdeApp->dcopClient()->findObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) );
} else
kdWarning() << "Error loading " << dcopService << endl;
}
diff --git a/kmail/mailsourceviewer.cpp b/kmail/mailsourceviewer.cpp
index d55fe0af8..ac6d60bc0 100644
--- a/kmail/mailsourceviewer.cpp
+++ b/kmail/mailsourceviewer.cpp
@@ -61,7 +61,7 @@ MailSourceViewer::MailSourceViewer( TQWidget *parent, const char *name )
accel->connectItem( accel->insertItem( TQt::Key_Escape ), this , TQ_SLOT( close() ));
accel->connectItem( accel->insertItem( TQt::Key_W+CTRL ), this , TQ_SLOT( close() ));
setWordWrap( KTextBrowser::NoWrap );
- KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+ KWin::setIcons(winId(), tdeApp->icon(), tdeApp->miniIcon());
}
MailSourceViewer::~MailSourceViewer()
diff --git a/kmail/main.cpp b/kmail/main.cpp
index fe5dee0a6..1f2d33ee2 100644
--- a/kmail/main.cpp
+++ b/kmail/main.cpp
@@ -58,7 +58,7 @@ int KMailApplication::newInstance()
if (!kmkernel)
return 0;
- if (!kmkernel->firstInstance() || !kapp->isRestored())
+ if (!kmkernel->firstInstance() || !tdeApp->isRestored())
kmkernel->handleCommandLine( true );
kmkernel->setFirstInstance(FALSE);
return 0;
@@ -87,14 +87,14 @@ int main(int argc, char *argv[])
// using KMail without KDE)
KNotifyClient::startDaemon();
- kapp->dcopClient()->suspend(); // Don't handle DCOP requests yet
+ tdeApp->dcopClient()->suspend(); // Don't handle DCOP requests yet
KMail::lockOrDie();
//local, do the init
KMKernel kmailKernel;
kmailKernel.init();
- kapp->dcopClient()->setDefaultObject( kmailKernel.objId() );
+ tdeApp->dcopClient()->setDefaultObject( kmailKernel.objId() );
// and session management
kmailKernel.doSessionManagement();
@@ -104,10 +104,10 @@ int main(int argc, char *argv[])
kmsetSignalHandler(kmsignalHandler);
- kapp->dcopClient()->resume(); // Ok. We are ready for DCOP requests.
+ tdeApp->dcopClient()->resume(); // Ok. We are ready for DCOP requests.
kmailKernel.setStartingUp( false ); // Starting up is finished
// Go!
- int ret = kapp->exec();
+ int ret = tdeApp->exec();
// clean up
kmailKernel.cleanup();
diff --git a/kmail/managesievescriptsdialog.cpp b/kmail/managesievescriptsdialog.cpp
index bd8d99558..509a39b53 100644
--- a/kmail/managesievescriptsdialog.cpp
+++ b/kmail/managesievescriptsdialog.cpp
@@ -37,7 +37,7 @@ KMail::ManageSieveScriptsDialog::ManageSieveScriptsDialog( TQWidget * parent, co
mWasActive( false )
{
setWFlags( WGroupLeader|WDestructiveClose );
- KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
+ KWin::setIcons( winId(), tdeApp->icon(), tdeApp->miniIcon() );
TQVBoxLayout * vlay = new TQVBoxLayout( plainPage(), 0, 0 );
diff --git a/kmail/searchwindow.cpp b/kmail/searchwindow.cpp
index 97f1e4b60..84f0d3852 100644
--- a/kmail/searchwindow.cpp
+++ b/kmail/searchwindow.cpp
@@ -127,7 +127,7 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
// proper fix in KWin ([email protected])
XDeleteProperty( tqt_xdisplay(), winId(), XA_WM_TRANSIENT_FOR );
#endif
- KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+ KWin::setIcons(winId(), tdeApp->icon(), tdeApp->miniIcon());
TDEConfig* config = KMKernel::config();
config->setGroup("SearchDialog");
diff --git a/kmail/secondarywindow.cpp b/kmail/secondarywindow.cpp
index a421209a5..cd4a91624 100644
--- a/kmail/secondarywindow.cpp
+++ b/kmail/secondarywindow.cpp
@@ -45,14 +45,14 @@ namespace KMail {
// modal subdialogs will only affect this window, not the other windows
setWFlags( getWFlags() | WGroupLeader );
- kapp->ref();
+ tdeApp->ref();
}
//---------------------------------------------------------------------------
SecondaryWindow::~SecondaryWindow()
{
- kapp->deref();
+ tdeApp->deref();
}
diff --git a/kmail/transportmanager.cpp b/kmail/transportmanager.cpp
index 7cb9d9acb..cd42388fd 100644
--- a/kmail/transportmanager.cpp
+++ b/kmail/transportmanager.cpp
@@ -59,7 +59,7 @@ namespace KMail {
int newId;
do
{
- newId = kapp->random();
+ newId = tdeApp->random();
} while ( usedIds.find(newId) != usedIds.end() );
return newId;
diff --git a/kmail/vacationdialog.cpp b/kmail/vacationdialog.cpp
index f02d42365..3b1c49323 100644
--- a/kmail/vacationdialog.cpp
+++ b/kmail/vacationdialog.cpp
@@ -43,7 +43,7 @@ namespace KMail {
const char * name, bool modal )
: KDialogBase( Plain, caption, Ok|Cancel|Default, Ok, parent, name, modal )
{
- KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
+ KWin::setIcons( winId(), tdeApp->icon(), tdeApp->miniIcon() );
static const int rows = 7;
int row = -1;
diff --git a/kmail/kmail_part.cpp b/kmail/kmail_part.cpp
index 55722c3c4..1add4e7ae 100644
--- a/kmail/kmail_part.cpp
+++ b/kmail/kmail_part.cpp
@@ -65,12 +65,12 @@ KMailPart::KMailPart(TQWidget *parentWidget, const char *widgetName,
mParentWidget( parentWidget )
{
kdDebug(5006) << "KMailPart()" << endl;
- kdDebug(5006) << " InstanceName: " << kapp->instanceName() << endl;
+ kdDebug(5006) << " InstanceName: " << tdeApp->instanceName() << endl;
setInstance(KMailFactory::instance());
kdDebug(5006) << "KMailPart()..." << endl;
- kdDebug(5006) << " InstanceName: " << kapp->instanceName() << endl;
+ kdDebug(5006) << " InstanceName: " << tdeApp->instanceName() << endl;
// import i18n data and icons from libraries:
KMail::insertLibraryCataloguesAndIcons();
@@ -81,7 +81,7 @@ KMailPart::KMailPart(TQWidget *parentWidget, const char *widgetName,
KMail::lockOrDie();
- kapp->dcopClient()->suspend(); // Don't handle DCOP requests yet
+ tdeApp->dcopClient()->suspend(); // Don't handle DCOP requests yet
//local, do the init
KMKernel *mKMailKernel = new KMKernel();
@@ -95,7 +95,7 @@ KMailPart::KMailPart(TQWidget *parentWidget, const char *widgetName,
mKMailKernel->recoverDeadLetters();
kmsetSignalHandler(kmsignalHandler);
- kapp->dcopClient()->resume(); // Ok. We are ready for DCOP requests.
+ tdeApp->dcopClient()->resume(); // Ok. We are ready for DCOP requests.
// create a canvas to insert our widget
TQWidget *canvas = new TQWidget(parentWidget, widgetName);
@@ -121,7 +121,7 @@ KMailPart::KMailPart(TQWidget *parentWidget, const char *widgetName,
kmkernel->inboxFolder()->close();
#else
mainWidget = new KMMainWidget( canvas, "mainWidget", this, actionCollection(),
- kapp->config());
+ tdeApp->config());
TQVBoxLayout *topLayout = new TQVBoxLayout(canvas);
topLayout->addWidget(mainWidget);
mainWidget->setFocusPolicy(TQWidget::ClickFocus);
@@ -153,7 +153,7 @@ KMailPart::KMailPart(TQWidget *parentWidget, const char *widgetName,
KMailPart::~KMailPart()
{
kdDebug(5006) << "Closing last KMMainWin: stopping mail check" << endl;
// Running TDEIO jobs prevent kapp from exiting, so we need to kill them
// if they are only about checking mail (not important stuff like moving messages)
kmkernel->abortMailCheck();
kmkernel->acctMgr()->cancelMailCheck();
@@ -153,7 +153,7 @@ KMailPart::KMailPart(TQWidget *parentWidget, const char *widgetName,
{
kdDebug(5006) << "Closing last KMMainWin: stopping mail check" << endl;
- // Running TDEIO jobs prevent kapp from exiting, so we need to kill them
+ // Running TDEIO jobs prevent tdeApp from exiting, so we need to kill them
// if they are only about checking mail (not important stuff like moving messages)
kmkernel->abortMailCheck();
diff --git a/kmail/kmmainwin.cpp b/kmail/kmmainwin.cpp
index d1abdab6e..120b1606a 100644
--- a/kmail/kmmainwin.cpp
+++ b/kmail/kmmainwin.cpp
@@ -33,7 +33,7 @@ KMMainWin::KMMainWin(TQWidget *)
// modal subdialogs will only affect this dialog, not the other windows
setWFlags( getWFlags() | WGroupLeader );
- kapp->ref();
+ tdeApp->ref();
(void) new TDEAction( i18n("New &Window"), "window-new", 0,
this, TQ_SLOT(slotNewMailReader()),
@@ -86,7 +86,7 @@ KMMainWin::~KMMainWin()
{
saveMainWindowSettings(KMKernel::config(), "Main Window");
KMKernel::config()->sync();
- kapp->deref();
+ tdeApp->deref();
if ( !kmkernel->haveSystemTrayApplet() ) {
// Check if this was the last KMMainWin
@@ -103,7 +103,7 @@ KMMainWin::~KMMainWin()
if ( not_withdrawn == 0 ) {
kdDebug(5006) << "Closing last KMMainWin: stopping mail check" << endl;
// Running TDEIO jobs prevent kapp from exiting, so we need to kill them
// if they are only about checking mail (not important stuff like moving messages)
kmkernel->abortMailCheck();
kmkernel->acctMgr()->cancelMailCheck();
@@ -206,10 +206,10 @@ void KMMainWin::slotConfigChanged()
//-----------------------------------------------------------------------------
bool KMMainWin::queryClose()
{
- if ( kapp->sessionSaving() )
+ if ( tdeApp->sessionSaving() )
writeConfig();
- if ( kmkernel->shuttingDown() || kapp->sessionSaving() || mReallyClose )
+ if ( kmkernel->shuttingDown() || tdeApp->sessionSaving() || mReallyClose )
return true;
return kmkernel->canQueryClose();
}
@@ -103,7 +103,7 @@ KMMainWin::~KMMainWin()
if ( not_withdrawn == 0 ) {
kdDebug(5006) << "Closing last KMMainWin: stopping mail check" << endl;
- // Running TDEIO jobs prevent kapp from exiting, so we need to kill them
+ // Running TDEIO jobs prevent tdeApp from exiting, so we need to kill them
// if they are only about checking mail (not important stuff like moving messages)
kmkernel->abortMailCheck();